<?php
	if ( ! function_exists( 'plastic_surgery_clinic_setup' ) ) :

	function plastic_surgery_clinic_setup() {
		$GLOBALS['content_width'] = apply_filters( 'plastic_surgery_clinic_content_width', 640 );
		
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'woocommerce' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'align-wide' );
		add_theme_support( 'wp-block-styles' );
		add_theme_support( 'responsive-embeds' );
		add_theme_support( 'html5', array( 'comment-list', 'search-form', 'comment-form', ) );
		add_theme_support( 'custom-logo', array(
			'height'      => 240,
			'width'       => 240,
			'flex-height' => true,
		) );

		add_theme_support( 'custom-background', array(
			'default-color' => 'ffffff'
		) );
	
	    register_nav_menus( array(
			'departments' => __( 'Departments Menu', 'plastic-surgery-clinic' ),
		) );

		/*
		 * This theme styles the visual editor to resemble the theme style,
		 * specifically font, colors, icons, and column width.
		 */
		add_editor_style( array( 'assets/css/editor-style.css', plastic_surgery_clinic_font_url() ) );

		// Theme Activation Notice
		global $pagenow;

		if (is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] )) {
			add_action('admin_notices', 'plastic_surgery_clinic_activation_notice');
		}

		// Theme Activation Redirects To Get Started Page
		if (is_admin() && ('themes.php' == $pagenow) && isset($_GET['activated']) && wp_get_theme()->get('TextDomain') === 'plastic-surgery-clinic') {
			wp_redirect(admin_url('themes.php?page=plastic_surgery_clinic_guide'));
		}
	}
	endif;

	add_action( 'after_setup_theme', 'plastic_surgery_clinic_setup' );

	// Notice after Theme Activation
	function plastic_surgery_clinic_activation_notice() {
		echo '<div class="notice notice-success is-dismissible welcome-notice">';
		echo '<p>'. esc_html__( 'Thank you for choosing Plastic Surgery Clinic Theme. Would like to have you on our Welcome page so that you can reap all the benefits of our Plastic Surgery Clinic Theme.', 'plastic-surgery-clinic' ) .'</p>';
		echo '<span><a href="'. esc_url( admin_url( 'themes.php?page=plastic_surgery_clinic_guide' ) ) .'" class="button button-primary">'. esc_html__( 'GET STARTED', 'plastic-surgery-clinic' ) .'</a></span>';
		echo '<span class="demo-btn""><a href="'. esc_url( 'https://www.vwthemes.net/plastic-surgery-clinic-pro/' ) .'" class="button button-primary" target=_blank>'. esc_html__( 'VIEW DEMO', 'plastic-surgery-clinic' ) .'</a></span>';
		echo '<span class="upgrade-btn"><a href="'. esc_url( 'https://www.vwthemes.com/themes/clinic-wordpress-theme/' ) .'" class="button button-primary" target=_blank>'. esc_html__( 'UPGRADE PRO', 'plastic-surgery-clinic' ) .'</a></span>';
		echo '</div>';
	}

	/* Theme Font URL */
	function plastic_surgery_clinic_font_url() {
		$font_url      = '';
		$font_family   = array(
			'Archivo:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900'	
		);
		$fonts_url = add_query_arg( array(
			'family' => implode( '&family=', $font_family ),
			'display' => 'swap',
		), 'https://fonts.googleapis.com/css2' );

		$contents = wptt_get_webfont_url( esc_url_raw( $fonts_url ) );
		return $contents;
	}

	add_action( 'wp_enqueue_scripts', 'plastic_surgery_clinic_enqueue_styles' );
	function plastic_surgery_clinic_enqueue_styles() {
		wp_enqueue_style( 'plastic-surgery-clinic-font', plastic_surgery_clinic_font_url(), array() );
    	$parent_style = 'plastic-surgery-clinic-basic-style'; // Style handle of parent theme.
    	
		wp_enqueue_style( 'bootstrap-style', get_template_directory_uri().'/assets/css/bootstrap.css' );
		wp_enqueue_style( $parent_style, get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'plastic-surgery-clinic-style', get_stylesheet_uri(), array( $parent_style ) );
		require get_theme_file_path( '/custom-style.php' );
		wp_add_inline_style( 'plastic-surgery-clinic-style',$vw_healthcare_custom_css );
		require get_parent_theme_file_path( '/custom-style.php' );
		wp_add_inline_style( 'plastic-surgery-clinic-basic-style',$vw_healthcare_custom_css );
		wp_enqueue_style( 'plastic-surgery-clinic-block-style', get_theme_file_uri('/assets/css/blocks.css') );
		wp_enqueue_script( 'plastic-surgery-clinic-custom-scripts-jquery', get_theme_file_uri() . '/assets/js/custom.js', array('jquery'),'' ,true );	
		wp_enqueue_style( 'plastic-surgery-clinic-block-patterns-style-frontend', get_theme_file_uri('/inc/block-patterns/css/block-frontend.css') );

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
		
	add_action( 'init', 'plastic_surgery_clinic_remove_parent_function');
	function plastic_surgery_clinic_remove_parent_function() {
		remove_action( 'admin_notices', 'vw_healthcare_activation_notice' );
		remove_action( 'admin_menu', 'vw_healthcare_gettingstarted' );
	}

	add_action( 'customize_register', 'plastic_surgery_clinic_customize_register', 11 );
	function plastic_surgery_clinic_customize_register($wp_customize) {
		global $wp_customize;
		$wp_customize->remove_section( 'vw_healthcare_go_pro' );
		$wp_customize->remove_section( 'vw_healthcare_get_started_link' );

		$wp_customize->remove_setting( 'vw_healthcare_phone_text' );
		$wp_customize->remove_control( 'vw_healthcare_phone_text' );
		$wp_customize->remove_setting( 'vw_healthcare_phone_number' );
		$wp_customize->remove_control( 'vw_healthcare_phone_number' );
		$wp_customize->remove_setting( 'vw_healthcare_location_text' );
		$wp_customize->remove_control( 'vw_healthcare_location_text' );
		$wp_customize->remove_setting( 'vw_healthcare_slider_image_overlay' );
		$wp_customize->remove_control( 'vw_healthcare_slider_image_overlay' );
		$wp_customize->remove_setting( 'vw_healthcare_slider_image_overlay_color' );
		$wp_customize->remove_control( 'vw_healthcare_slider_image_overlay_color' );

		$wp_customize->add_setting( 'plastic_surgery_clinic_email_address', array(
			'default'           => '',
			'sanitize_callback' => 'sanitize_email'
		) );
		$wp_customize->add_control( 'plastic_surgery_clinic_email_address', array(
			'label'    => __( 'Email Address', 'plastic-surgery-clinic' ),
			'input_attrs' => array(
	            'placeholder' => __( 'example@gmail.com', 'plastic-surgery-clinic' ),
	        ),
			'section'  => 'vw_healthcare_header',
			'type'     => 'text'
		) );

		$wp_customize->add_setting( 'plastic_surgery_clinic_notice_section_text', array(
			'default'           => '',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'plastic_surgery_clinic_notice_section_text', array(
			'label'    => __( 'Notice Text', 'plastic-surgery-clinic' ),
			'input_attrs' => array(
	            'placeholder' => __( 'In accordance with the latest Government guidelines on COVID-19.', 'plastic-surgery-clinic' ),
	        ),
			'section'  => 'vw_healthcare_header',
			'type'     => 'text'
		) );

		$wp_customize->add_setting( 'plastic_surgery_clinic_notice_section_btn_text', array(
			'default'           => '',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'plastic_surgery_clinic_notice_section_btn_text', array(
			'label'    => __( 'Notice Button Text', 'plastic-surgery-clinic' ),
			'input_attrs' => array(
	            'placeholder' => __( 'Get More Info', 'plastic-surgery-clinic' ),
	        ),
			'section'  => 'vw_healthcare_header',
			'type'     => 'text'
		) );

		$wp_customize->add_setting('vw_healthcare_notice_section_btn_link',array(
			'default'=> '',
			'sanitize_callback'	=> 'esc_url_raw'
		));
		$wp_customize->add_control('vw_healthcare_notice_section_btn_link',array(
			'label'	=> esc_html__('Button Link','plastic-surgery-clinic'),
			'input_attrs' => array(
	            'placeholder' => esc_html__( 'https://www.example.com/', 'plastic-surgery-clinic' ),
	        ),
			'section'=> 'vw_healthcare_header',
			'type'=> 'url'
		));

		//About Section
		$wp_customize->add_section( 'plastic_surgery_clinic_about_section', array(
	    	'title'      => __( 'About Section', 'plastic-surgery-clinic' ),
			'panel' => 'vw_healthcare_panel_id',
			'priority' => 11,
		));

		$wp_customize->add_setting( 'plastic_surgery_clinic_section_small_title', array(
			'default'           => '',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'plastic_surgery_clinic_section_small_title', array(
			'label'    => __( 'Add Section Small Title', 'plastic-surgery-clinic' ),
			'input_attrs' => array(
	            'placeholder' => __( 'Known Symptoms in Corona', 'plastic-surgery-clinic' ),
	        ),
			'section'  => 'plastic_surgery_clinic_about_section',
			'type'     => 'text'
		) );

		$wp_customize->add_setting('plastic_surgery_clinic_section_title',array(
			'default'=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
		)); 
		$wp_customize->add_control('plastic_surgery_clinic_section_title',array(
			'label'	=> esc_html__('Add Heading','plastic-surgery-clinic'),
			'input_attrs' => array(
	            'placeholder' => esc_html__( 'Covid Symptoms', 'plastic-surgery-clinic' ),
	        ),
			'section'=> 'plastic_surgery_clinic_about_section',
			'type'=> 'text'
		));

		$wp_customize->add_setting('plastic_surgery_clinic_section_text',array(
			'default'=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
		)); 
		$wp_customize->add_control('plastic_surgery_clinic_section_text',array(
			'label'	=> esc_html__('Add Section Text','plastic-surgery-clinic'),
			'input_attrs' => array(
	            'placeholder' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut.', 'plastic-surgery-clinic' ),
	        ),
			'section'=> 'plastic_surgery_clinic_about_section',
			'type'=> 'text'
		));

		$categories = get_categories();
		$cat_posts = array();
			$i = 0;
			$cat_posts[]='Select';	
		foreach($categories as $category){
			if($i==0){
				$default = $category->slug;
				$i++;
			}
			$cat_posts[$category->slug] = $category->name;
		}

		$wp_customize->add_setting('plastic_surgery_clinic_symptoms_category',array(
			'default'	=> 'select',
			'sanitize_callback' => 'plastic_surgery_clinic_sanitize_choices',
		));
		$wp_customize->add_control('plastic_surgery_clinic_symptoms_category',array(
			'type'    => 'select',
			'choices' => $cat_posts,
			'label' => __('Select Symptoms Category','plastic-surgery-clinic'),
			'section' => 'plastic_surgery_clinic_about_section',
		));

		$wp_customize->add_setting('plastic_surgery_clinic_symptoms_image',array(
			'default'	=> '',
			'sanitize_callback'	=> 'esc_url_raw',
		));
		$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'plastic_surgery_clinic_symptoms_image',array(
	        'label' => __('Symptoms Image','plastic-surgery-clinic'),
	        'section' => 'plastic_surgery_clinic_about_section'
		)));
	}

	add_action( 'customize_register', 'plastic_surgery_clinic_typography_customize_register', 12 );
	function plastic_surgery_clinic_typography_customize_register( $wp_customize ) {
		$wp_customize->remove_control( 'vw_healthcare_second_color' );
	}

	define('PLASTIC_SURGERY_CLINIC_FREE_THEME_DOC',__('https://www.vwthemesdemo.com/docs/free-plastic-surgery-clinic/','plastic-surgery-clinic'));
	define('PLASTIC_SURGERY_CLINIC_SUPPORT',__('https://wordpress.org/support/theme/plastic-surgery-clinic/','plastic-surgery-clinic'));
	define('PLASTIC_SURGERY_CLINIC_REVIEW',__('https://wordpress.org/support/theme/plastic-surgery-clinic/reviews','plastic-surgery-clinic'));
	define('PLASTIC_SURGERY_CLINIC_BUY_NOW',__('https://www.vwthemes.com/themes/clinic-wordpress-theme/','plastic-surgery-clinic'));
	define('PLASTIC_SURGERY_CLINIC_LIVE_DEMO',__('https://www.vwthemes.net/plastic-surgery-clinic-pro/','plastic-surgery-clinic'));
	define('PLASTIC_SURGERY_CLINIC_PRO_DOC',__('https://www.vwthemesdemo.com/docs/vw-plastic-surgery-clinic-pro/','plastic-surgery-clinic'));
	define('PLASTIC_SURGERY_CLINIC_FAQ',__('https://www.vwthemes.com/faqs/','plastic-surgery-clinic'));
	define('PLASTIC_SURGERY_CLINIC_CONTACT',__('https://www.vwthemes.com/contact/','plastic-surgery-clinic'));
	define('PLASTIC_SURGERY_CLINIC_CHILD_THEME',__('https://developer.wordpress.org/themes/advanced-topics/child-themes/','plastic-surgery-clinic'));
	define('PLASTIC_SURGERY_CLINIC_CREDIT',__('https://www.vwthemes.com/themes/free-plastic-surgery-wordpress-theme/','plastic-surgery-clinic'));

	if ( ! function_exists( 'plastic_surgery_clinic_credit' ) ) {
		function plastic_surgery_clinic_credit(){
			echo "<a href=".esc_url(PLASTIC_SURGERY_CLINIC_CREDIT)." target='_blank'>". esc_html__('Clinic WordPress Theme','plastic-surgery-clinic') ."</a>";
		}
	}



	if ( ! defined( 'VW_HEALTHCARE_GO_PRO' ) ) {
		define( 'VW_HEALTHCARE_GO_PRO', 'https://www.vwthemes.com/themes/clinic-wordpress-theme/');
	}

	if ( ! defined( 'VW_HEALTHCARE_GETSTARTED_URL' ) ) {
	define( 'VW_HEALTHCARE_GETSTARTED_URL', 'themes.php?page=plastic_surgery_clinic_guide');
	}

	function plastic_surgery_clinic_sanitize_choices( $input, $setting ) {
	    global $wp_customize; 
	    $control = $wp_customize->get_control( $setting->id ); 
	    if ( array_key_exists( $input, $control->choices ) ) {
	        return $input;
	    } else {
	        return $setting->default;
	    }
	}

	/* Theme Widgets Setup */

	function plastic_surgery_clinic_widgets_init() {
		register_sidebar( array(
			'name'          => __( 'Footer Navigation 1', 'plastic-surgery-clinic' ),
			'description'   => __( 'Appears on footer 1', 'plastic-surgery-clinic' ),
			'id'            => 'footer-1',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );

		register_sidebar( array(
			'name'          => __( 'Footer Navigation 2', 'plastic-surgery-clinic' ),
			'description'   => __( 'Appears on footer 2', 'plastic-surgery-clinic' ),
			'id'            => 'footer-2',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );

		register_sidebar( array(
			'name'          => __( 'Footer Navigation 3', 'plastic-surgery-clinic' ),
			'description'   => __( 'Appears on footer 3', 'plastic-surgery-clinic' ),
			'id'            => 'footer-3',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );

		register_sidebar( array(
			'name'          => __( 'Footer Navigation 4', 'plastic-surgery-clinic' ),
			'description'   => __( 'Appears on footer 4', 'plastic-surgery-clinic' ),
			'id'            => 'footer-4',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );

		register_sidebar( array(
			'name'          => __( 'Social Icon', 'plastic-surgery-clinic' ),
			'description'   => __( 'Appears on topbar', 'plastic-surgery-clinic' ),
			'id'            => 'social-widget',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );
	}
	add_action( 'widgets_init', 'plastic_surgery_clinic_widgets_init' );

	/**
 * Enqueue block editor style
 */
function plastic_surgery_clinic_block_editor_styles() {
	wp_enqueue_style( 'plastic-surgery-clinic-font', plastic_surgery_clinic_font_url(), array() );
    wp_enqueue_style( 'plastic-surgery-clinic-block-patterns-style-editor', get_theme_file_uri( '/inc/block-patterns/css/block-editor.css' ), false, '1.0', 'all' );
    wp_enqueue_style( 'font-awesome-css', get_template_directory_uri().'/css/fontawesome-all.css' );
}
add_action( 'enqueue_block_editor_assets', 'plastic_surgery_clinic_block_editor_styles' );

// Customizer Pro
load_template( ABSPATH . WPINC . '/class-wp-customize-section.php' );

class Plastic_Surgery_Clinic_Customize_Section_Pro extends WP_Customize_Section {
	public $type = 'plastic-surgery-clinic';
	public $pro_text = '';
	public $pro_url = '';
	public function json() {
		$json = parent::json();
		$json['pro_text'] = $this->pro_text;
		$json['pro_url']  = esc_url( $this->pro_url );
		return $json;
	}
	protected function render_template() { ?>
		<li id="accordion-section-{{ data.id }}" class="accordion-section control-section control-section-{{ data.type }} cannot-expand">
			<h3 class="accordion-section-title">
				{{ data.title }}
				<# if ( data.pro_text && data.pro_url ) { #>
					<a href="{{ data.pro_url }}" class="button button-secondary alignright" target="_blank">{{ data.pro_text }}</a>
				<# } #>
			</h3>
		</li>
	<?php }
}

final class Plastic_Surgery_Clinic_Customize {
	public static function get_instance() {
		static $instance = null;
		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}
		return $instance;
	}
	private function __construct() {}
	private function setup_actions() {
		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );
		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}
	public function sections( $manager ) {
		// Register custom section types.
		$manager->register_section_type( 'Plastic_Surgery_Clinic_Customize_Section_Pro' );
		// Register sections.
		$manager->add_section( new Plastic_Surgery_Clinic_Customize_Section_Pro( $manager, 'plastic_surgery_clinic_upgrade_pro_link',
		array(
			'priority'   => 1,
			'title'    => esc_html__( 'SURGERY CLINIC PRO', 'plastic-surgery-clinic' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'plastic-surgery-clinic' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/clinic-wordpress-theme/'),
		) ) );

		// Register sections.
		$manager->add_section(new Plastic_Surgery_Clinic_Customize_Section_Pro($manager,'plastic_surgery_clinic_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'plastic-surgery-clinic' ),
			'pro_text' => esc_html__( 'DOCS', 'plastic-surgery-clinic' ),
			'pro_url'  => esc_url('https://www.vwthemesdemo.com/docs/vw-health-care-pro/'),
		)));
	}
	public function enqueue_control_scripts() {
		wp_enqueue_script( 'plastic-surgery-clinic-customize-controls', get_stylesheet_directory_uri() . '/assets/js/customize-controls-child.js', array( 'customize-controls' ) );
		wp_enqueue_style( 'plastic-surgery-clinic-customize-controls', get_stylesheet_directory_uri() . '/assets/css/customize-controls-child.css' );
	}
}
Plastic_Surgery_Clinic_Customize::get_instance();

/* getstart */
require get_theme_file_path('/inc/getstart/getstart.php');

/* Plugin Activation */
require get_theme_file_path() . '/inc/getstart/plugin-activation.php';

/* Tgm */
require get_theme_file_path() . '/inc/tgm/tgm.php';

/* Block Pattern */
require get_theme_file_path('/inc/block-patterns/block-patterns.php');